@@ -8,13 +8,8 @@ function (object, resp.patterns = NULL, method = c("EB", "EAP", "MI"), B = 5, ro
     nx <- nrow(X)
     p <- nrow(betas)
     method <- match.arg(method)
-    vals <- lapply(1:ncol(X), function (i) c(0,1))
-    res <- if (any(is.na(object$X))) {
-        data.frame(X)
-    } else {
-        Obs <- observedFreqs(object, X, vals)
-        data.frame(X, Obs = Obs, Exp = fits[, ncol(fits)])        
-    }
+    Obs <- observedFreqs(object, X)
+    res <- data.frame(X, Obs = Obs, Exp = fits[, ncol(fits)])        
     names(res)[1:p] <- rownames(betas)
     environment(fscores.r) <- environment()
     res <- fscores.r(betas, X, method)
