@@ -12,6 +12,9 @@ function (object, resp.patterns = NULL,
         if (!is.matrix(resp.patterns) && !is.data.frame(resp.patterns))
             stop("'resp.patterns' should be a matrix or a data.frame.\n")
         resp.patterns <- data.matrix(resp.patterns)
+        resp.patterns <- apply(resp.patterns, 2, function (x) { y <- x[!is.na(x)]; if (any(y == 0)) x + 1 else x })
+        if (!is.matrix(resp.patterns))
+            resp.patterns <- t(resp.patterns)
         if (ncol(resp.patterns) != p)
             stop("the number of items in ", deparse(substitute(object)), " and the number of columns of 'resp.patterns' do not much.\n")
         check.items <- vector("logical", p)
@@ -54,7 +57,6 @@ function (object, resp.patterns = NULL,
             rownames(res) <- if (!is.null(resp.patterns) && !is.null(nams <- rownames(resp.patterns))) nams else NULL
             res
         })
-        print(out)
         for (i in seq_along(out)) {
             if (is.factor(object$X[[i]]))
                 colnames(out[[i]]) <- levels(object$X[[i]])
