@@ -23,9 +23,10 @@ function (betas, X, method) {
         Z <- object$GH$Z
         GHw <- object$GH$GHw
         pr <- probs(Z %*% t(betas))
+        mX <- 1 - X
         if (any(na.ind <- is.na(X)))
-            X[na.ind] <- 0
-        p.xz <- exp(X %*% t(log(pr)) + (1 - X) %*% t(log(1 - pr)))
+            X[na.ind] <- mX[na.ind] <- 0
+        p.xz <- exp(X %*% t(log(pr)) + mX %*% t(log(1 - pr)))
         p.x <- c(p.xz %*% GHw)
         p.zx <- p.xz / p.x
         res$z1 <- c(p.zx %*% (Z[, 2] * GHw))
