@@ -8,8 +8,8 @@ function (formula, constraint = NULL, IRT.param, start.val = NULL, na.action = N
     if ((!is.data.frame(X) & !is.matrix(X)) || ncol(X) == 1)
         stop("\nthe left-hand side of 'formula' must be either a numeric matrix or a data.frame, with at least two columns.\n")    
     X <- data.matrix(X)
-    if (!all(its <- apply(X, 2, function (x) { x <- x[!is.na(x)]; length(unique(x)) } ) == 2))
-        stop("'data' contain more that 2 distinct values for item(s): ", paste(which(!its), collapse = ", "))
+    if (any(its <- apply(X, 2, function (x) { x <- x[!is.na(x)]; length(unique(x)) } ) > 2))
+        stop("'data' contain more that 2 distinct values for item(s): ", paste(which(its), collapse = ", "))
     X <- apply(X, 2, function (x) if (all(unique(x) %in% c(1, 0, NA))) x else x - 1)    
     if (!is.null(na.action))
         X <- na.action(X)
